@@ -1,9 +1,9 @@
 # kojixmlrpc - an XMLRPC interface for koji.
-# Copyright (c) 2005-2012 Red Hat
+# Copyright (c) 2005-2014 Red Hat, Inc.
 #
 #    Koji is free software; you can redistribute it and/or
 #    modify it under the terms of the GNU Lesser General Public
-#    License as published by the Free Software Foundation; 
+#    License as published by the Free Software Foundation;
 #    version 2.1 of the License.
 #
 #    This software is distributed in the hope that it will be useful,
@@ -28,6 +28,7 @@ import traceback
 import types
 import pprint
 import resource
+import xmlrpclib
 from xmlrpclib import getparser,dumps,Fault
 from koji.server import WSGIWrapper
 
@@ -40,6 +41,22 @@ import koji.util
 from koji.context import context
 
 
+# Workaround to allow xmlrpclib deal with iterators
+class Marshaller(xmlrpclib.Marshaller):
+
+    dispatch = xmlrpclib.Marshaller.dispatch.copy()
+
+    def dump_generator(self, value, write):
+        dump = self.__dump
+        write("<value><array><data>\n")
+        for v in value:
+            dump(v, write)
+        write("</data></array></value>\n")
+    dispatch[types.GeneratorType] = dump_generator
+
+xmlrpclib.Marshaller = Marshaller
+
+
 class HandlerRegistry(object):
     """Track handlers for RPC calls"""
 
@@ -175,7 +192,7 @@ class HandlerAccess(object):
         return self.__reg.get(__name)(*args, **kwargs)
 
     def get(self, name):
-        return self.__Reg.get(name)
+        return self.__reg.get(name)
 
 
 class ModXMLRPCRequestHandler(object):
@@ -196,10 +213,15 @@ class ModXMLRPCRequestHandler(object):
 
     def _read_request(self, stream):
         parser, unmarshaller = getparser()
+        rlen = 0
+        maxlen = opts.get('MaxRequestLength', None)
         while True:
             chunk = stream.read(8192)
             if not chunk:
                 break
+            rlen += len(chunk)
+            if maxlen and rlen > maxlen:
+                raise koji.GenericError, 'Request too long'
             parser.feed(chunk)
         parser.close()
         return unmarshaller.close(), unmarshaller.getmethodname()
@@ -270,7 +292,7 @@ class ModXMLRPCRequestHandler(object):
         if context.opts.get('LockOut') and \
             context.method not in ('login', 'krbLogin', 'sslLogin', 'logout') and \
             not context.session.hasPerm('admin'):
-                raise koji.ServerOffline, "Server disabled for maintenance"
+            raise koji.ServerOffline, "Server disabled for maintenance"
 
     def _dispatch(self, method, params):
         func = self._get_handler(method)
@@ -360,20 +382,33 @@ def load_config(environ):
           will disappear in a future version of Koji
     """
     logger = logging.getLogger("koji")
-    #get our config file
+    #get our config file(s)
     if 'modpy.opts' in environ:
         modpy_opts = environ.get('modpy.opts')
         cf = modpy_opts.get('ConfigFile', None)
-    else:
-        cf = environ.get('koji.hub.ConfigFile', '/etc/koji-hub/hub.conf')
-        modpy_opts = {}
-    if cf:
         # to aid in the transition from PythonOptions to hub.conf, we only load
         # the configfile if it is explicitly configured
-        config = RawConfigParser()
-        config.read(cf)
+        if cf == '/etc/koji-hub/hub.conf':
+            cfdir =  modpy_opts.get('ConfigDir', '/etc/koji-hub/hub.conf.d')
+        else:
+            cfdir =  modpy_opts.get('ConfigDir', None)
+        if not cf and not cfdir:
+            logger.warn('Warning: configuring Koji via PythonOptions is deprecated. Use hub.conf')
     else:
-        logger.warn('Warning: configuring Koji via PythonOptions is deprecated. Use hub.conf')
+        cf = environ.get('koji.hub.ConfigFile', '/etc/koji-hub/hub.conf')
+        cfdir = environ.get('koji.hub.ConfigDir', '/etc/koji-hub/hub.conf.d')
+        modpy_opts = {}
+    if cfdir:
+        configs = koji.config_directory_contents(cfdir)
+    else:
+        configs = []
+    if cf and os.path.isfile(cf):
+        configs.append(cf)
+    if configs:
+        config = RawConfigParser()
+        config.read(configs)
+    else:
+        config = None
     cfgmap = [
         #option, type, default
         ['DBName', 'string', None],
@@ -426,6 +461,7 @@ def load_config(environ):
         ['RLIMIT_STACK', 'string', None],
 
         ['MemoryWarnThreshold', 'integer', 5000],
+        ['MaxRequestLength', 'integer', 4194304],
 
         ['LockOut', 'boolean', False],
         ['ServerOffline', 'boolean', False],
@@ -433,7 +469,7 @@ def load_config(environ):
     ]
     opts = {}
     for name, dtype, default in cfgmap:
-        if cf:
+        if config:
             key = ('hub', name)
             if config.has_option(*key):
                 if dtype == 'integer':
@@ -458,7 +494,7 @@ def load_config(environ):
         opts['DBHost'] = opts['DBhost']
     # load policies
     # (only from config file)
-    if cf and config.has_section('policy'):
+    if config and config.has_section('policy'):
         #for the moment, we simply transfer the policy conf to opts
         opts['policy'] = dict(config.items('policy'))
     else:
@@ -533,7 +569,7 @@ def get_policy(opts, plugins):
                         if pname != test.policy:
                             continue
                     elif pname not in test.policy:
-                            continue
+                        continue
                 # in case of name overlap, last one wins
                 # hence plugins can override builtin tests
                 merged[name] = test
