@@ -1,11 +1,11 @@
 # Python module
 # Common functions
 
-# Copyright (c) 2005-2012 Red Hat
+# Copyright (c) 2005-2014 Red Hat, Inc.
 #
 #    Koji is free software; you can redistribute it and/or
 #    modify it under the terms of the GNU Lesser General Public
-#    License as published by the Free Software Foundation; 
+#    License as published by the Free Software Foundation;
 #    version 2.1 of the License.
 #
 #    This software is distributed in the hope that it will be useful,
@@ -19,6 +19,7 @@
 #
 # Authors:
 #       Mike McLean <mikem@redhat.com>
+#       Mike Bonnet <mikeb@redhat.com>
 
 import sys
 try:
@@ -56,7 +57,7 @@ import xmlrpclib
 import xml.sax
 import xml.sax.handler
 from xmlrpclib import loads, dumps, Fault
-#import OpenSSL.SSL
+import OpenSSL
 import zipfile
 
 def _(args):
@@ -322,6 +323,9 @@ class ParameterError(GenericError):
     """Raised when an rpc call receives incorrect arguments"""
     faultCode = 1019
 
+class ImportError(GenericError):
+    """Raised when an import fails"""
+    faultCode = 1020
 
 class MultiCallInProgress(object):
     """
@@ -986,7 +990,7 @@ def parse_pom(path=None, contents=None):
         raise GenericError, 'either a path to a pom file or the contents of a pom file must be specified'
 
     # A common problem is non-UTF8 characters in XML files, so we'll convert the string first
-    
+
     contents = fixEncoding(contents)
 
     try:
@@ -1282,6 +1286,8 @@ def genMockConfig(name, arch, managed=False, repoid=None, tag_name=None, **opts)
         # Don't let a build last more than 24 hours
         'rpmbuild_timeout': opts.get('rpmbuild_timeout', 86400)
     }
+    if opts.get('package_manager'):
+        config_opts['package_manager'] = opts['package_manager']
 
     # bind_opts are used to mount parts (or all of) /dev if needed.
     # See kojid::LiveCDTask for a look at this option in action.
@@ -1435,6 +1441,22 @@ def openRemoteFile(relpath, topurl=None, topdir=None):
     return fo
 
 
+def config_directory_contents(dir_name):
+    configs = []
+    try:
+        conf_dir_contents = os.listdir(dir_name)
+    except OSError, exception:
+        if exception.errno != errno.ENOENT:
+            raise
+    else:
+        for name in sorted(conf_dir_contents):
+            if not name.endswith('.conf'):
+                continue
+            config_full_name = os.path.join(dir_name, name)
+            configs.append(config_full_name)
+    return configs
+
+
 class PathInfo(object):
     # ASCII numbers and upper- and lower-case letter for use in tmpdir()
     ASCII_CHARS = [chr(i) for i in range(48, 58) + range(65, 91) + range(97, 123)]
@@ -1918,6 +1940,9 @@ class ClientSession(object):
                 except (SystemExit, KeyboardInterrupt):
                     #(depending on the python version, these may or may not be subclasses of Exception)
                     raise
+                except OpenSSL.SSL.Error as e:
+                    # There's no point in retrying this
+                    raise
                 except Exception, e:
                     self._close_connection()
                     if not self.logged_in:
@@ -1931,8 +1956,10 @@ class ClientSession(object):
                     if self.logger.isEnabledFor(logging.DEBUG):
                         tb_str = ''.join(traceback.format_exception(*sys.exc_info()))
                         self.logger.debug(tb_str)
-                    self.logger.info("Try #%d for call %d (%s) failed: %s", tries, self.callnum, name, e)
-                time.sleep(interval)
+                    self.logger.info("Try #%s for call %s (%s) failed: %s", tries, self.callnum, name, e)
+                if tries > 1:
+                    # first retry is immediate, after that we honor retry_interval
+                    time.sleep(interval)
             #not reached
 
     def multiCall(self, strict=False):
@@ -1971,7 +1998,7 @@ class ClientSession(object):
         #    raise AttributeError, "no attribute %r" % name
         return VirtualMethod(self._callMethod,name)
 
-    def fastUpload(self, localfile, path, name=None, callback=None, blocksize=1048576):
+    def fastUpload(self, localfile, path, name=None, callback=None, blocksize=1048576, overwrite=False):
         if not self.logged_in:
             raise ActionNotAllowed, 'You must be logged in to upload files'
         if name is None:
@@ -1991,7 +2018,7 @@ class ClientSession(object):
             chunk = fo.read(blocksize)
             if not chunk:
                 break
-            result = self._callMethod('rawUpload', (chunk, ofs, path, name))
+            result = self._callMethod('rawUpload', (chunk, ofs, path, name), {'overwrite':overwrite})
             if self.retries > 1:
                 problems = True
             hexdigest = util.adler32_constructor(chunk).hexdigest()
@@ -2015,10 +2042,10 @@ class ClientSession(object):
             chk_opts['verify'] = 'adler32'
         result = self._callMethod('checkUpload', (path, name), chk_opts)
         if int(result['size']) != ofs:
-            raise koji.GenericError, "Uploaded file is wrong length: %s/%s, %s != %s" \
+            raise GenericError, "Uploaded file is wrong length: %s/%s, %s != %s" \
                     % (path, name, result['sumlength'], ofs)
         if problems and result['hexdigest'] != full_chksum.hexdigest():
-            raise koji.GenericError, "Uploaded file has wrong checksum: %s/%s, %s != %s" \
+            raise GenericError, "Uploaded file has wrong checksum: %s/%s, %s != %s" \
                     % (path, name, result['hexdigest'], full_chksum.hexdigest())
         self.logger.debug("Fast upload: %s complete. %i bytes in %.1f seconds", localfile, size, t2)
 
@@ -2045,10 +2072,10 @@ class ClientSession(object):
         request = chunk
         return handler, headers, request
 
-    def uploadWrapper(self, localfile, path, name=None, callback=None, blocksize=1048576):
+    def uploadWrapper(self, localfile, path, name=None, callback=None, blocksize=1048576, overwrite=True):
         """upload a file in chunks using the uploadFile call"""
         if self.opts.get('use_fast_upload'):
-            self.fastUpload(localfile, path, name, callback, blocksize)
+            self.fastUpload(localfile, path, name, callback, blocksize, overwrite)
             return
         if name is None:
             name = os.path.basename(localfile)
@@ -2056,10 +2083,12 @@ class ClientSession(object):
         # check if server supports fast upload
         try:
             check = self._callMethod('checkUpload', (path, name))
+            # fast upload was introduced in 1.7.1, earlier servers will not
+            # recognise this call and return an error
         except GenericError:
             pass
         else:
-            self.fastUpload(localfile, path, name, callback, blocksize)
+            self.fastUpload(localfile, path, name, callback, blocksize, overwrite)
             return
 
         start=time.time()
@@ -2321,7 +2350,7 @@ def _taskLabel(taskInfo):
     elif method == 'dependantTask':
         if taskInfo.has_key('request'):
             extra = ', '.join([subtask[0] for subtask in taskInfo['request'][1]])
-    elif method == 'chainbuild':
+    elif method in ('chainbuild', 'chainmaven'):
         if taskInfo.has_key('request'):
             extra = taskInfo['request'][1]
     elif method == 'waitrepo':
