@@ -1,10 +1,10 @@
 # Code shared by various Koji daemons
 
-# Copyright (c) 2010 Red Hat, Inc.
+# Copyright (c) 2010-2014 Red Hat, Inc.
 #
 #    Koji is free software; you can redistribute it and/or
 #    modify it under the terms of the GNU Lesser General Public
-#    License as published by the Free Software Foundation; 
+#    License as published by the Free Software Foundation;
 #    version 2.1 of the License.
 #
 #    This software is distributed in the hope that it will be useful,
@@ -266,7 +266,7 @@ class SCM(object):
 
         # check for validity: params should be empty, query may be empty, everything else should be populated
         if params :
-            raise koji.GenericError, 'Unable to parse SCM URL: %s . Param element %s should be empty.' % (self.url,param)
+            raise koji.GenericError, 'Unable to parse SCM URL: %s . Params element %s should be empty.' % (self.url, params)
         if not scheme :
             raise koji.GenericError, 'Unable to parse SCM URL: %s . Could not find the scheme element.' % self.url
         if not netloc :
