@@ -1,9 +1,9 @@
 # koji plugin module
-# Copyright (c) 2008 Red Hat
+# Copyright (c) 2008-2014 Red Hat, Inc.
 #
 #    Koji is free software; you can redistribute it and/or
 #    modify it under the terms of the GNU Lesser General Public
-#    License as published by the Free Software Foundation; 
+#    License as published by the Free Software Foundation;
 #    version 2.1 of the License.
 #
 #    This software is distributed in the hope that it will be useful,
@@ -17,6 +17,7 @@
 #
 # Authors:
 #       Mike McLean <mikem@redhat.com>
+#       Mike Bonnet <mikeb@redhat.com>
 
 import imp
 import koji
@@ -35,6 +36,8 @@ callbacks = {
     'postBuildStateChange':   [],
     'preImport':              [],
     'postImport':             [],
+    'preRPMSign':             [],
+    'postRPMSign':            [],
     'preTag':                 [],
     'postTag':                [],
     'preUntag':               [],
@@ -115,12 +118,12 @@ def export_in(module, alias=None):
     """
     def dec(f):
         if alias is None:
-            alias = "%s.%s" % (module, f.__name__)
+            local_alias = "%s.%s" % (module, f.__name__)
         else:
-            alias = "%s.%s" % (module, alias)
+            local_alias = "%s.%s" % (module, alias)
         setattr(f, 'exported', True)
         setattr(f, 'export_module', module)
-        setattr(f, 'export_alias', alias)
+        setattr(f, 'export_alias', local_alias)
         return f
     return dec
 
