@@ -1,5 +1,5 @@
 # Koji callback for sending notifications about events to a messagebus (amqp broker)
-# Copyright (c) 2009 Red Hat, Inc.
+# Copyright (c) 2009-2014 Red Hat, Inc.
 #
 # Authors:
 #     Mike Bonnet <mikeb@redhat.com>
@@ -22,19 +22,19 @@ session = None
 target = None
 
 def connect_timeout(host, port, timeout):
-  for res in socket.getaddrinfo(host, port, 0, socket.SOCK_STREAM):
-    af, socktype, proto, canonname, sa = res
-    sock = socket.socket(af, socktype, proto)
-    sock.settimeout(timeout)
-    try:
-      sock.connect(sa)
-      break
-    except socket.error, msg:
-      sock.close()
-  else:
-    # If we got here then we couldn't connect (yet)
-    raise
-  return sock
+    for res in socket.getaddrinfo(host, port, 0, socket.SOCK_STREAM):
+        af, socktype, proto, canonname, sa = res
+        sock = socket.socket(af, socktype, proto)
+        sock.settimeout(timeout)
+        try:
+            sock.connect(sa)
+            break
+        except socket.error, msg:
+            sock.close()
+    else:
+        # If we got here then we couldn't connect (yet)
+        raise
+    return sock
 
 class tlstimeout(qpid.messaging.transports.tls):
     def __init__(self, conn, host, port):
@@ -168,6 +168,8 @@ def get_message_headers(msgtype, *args, **kws):
         headers['tag'] = kws['tag']['name']
         headers['package'] = kws['package']['name']
     elif msgtype == 'TaskStateChange':
+        headers['id'] = kws['info']['id']
+        headers['parent'] = kws['info']['parent']
         headers['method'] = kws['info']['method']
         headers['attribute'] = kws['attribute']
         headers['old'] = kws['old']
