@@ -2,11 +2,11 @@
 
 # Koji daemon that runs in a Windows VM and executes commands associated
 # with a task.
-# Copyright (c) 2010 Red Hat
+# Copyright (c) 2010-2014 Red Hat, Inc.
 #
 #    Koji is free software; you can redistribute it and/or
 #    modify it under the terms of the GNU Lesser General Public
-#    License as published by the Free Software Foundation; 
+#    License as published by the Free Software Foundation;
 #    version 2.1 of the License.
 #
 #    This software is distributed in the hope that it will be useful,
@@ -276,7 +276,7 @@ class WindowsBuild(object):
                 continue
             tokens = entry.split(':')
             filename = tokens[0]
-            for var in ('name', 'version', 'release'): 
+            for var in ('name', 'version', 'release'):
                 filename = filename.replace('$' + var, getattr(self, var))
             metadata = {}
             metadata['platforms'] = tokens[1].split(',')
@@ -589,7 +589,7 @@ def get_mgmt_server():
                  macaddr, gateway, MANAGER_PORT)
     server = xmlrpclib.ServerProxy('http://%s:%s/' %
                                    (gateway, MANAGER_PORT), allow_none=True)
-    # we would set a timeout on the socket here, but that is apparently not 
+    # we would set a timeout on the socket here, but that is apparently not
     # supported by python/cygwin/Windows
     task_port = server.getPort(macaddr)
     logger.debug('found task-specific port %s', task_port)
@@ -727,6 +727,10 @@ def main():
         thread.daemon = True
         thread.start()
 
+        # xmlrpclib is not thread-safe, create a new ServerProxy
+        # instance so we're not sharing with the stream_logs thread
+        server = get_mgmt_server()
+
         build = WindowsBuild(server)
         builds.append(build)
         results = build.run()
